# brainmaps-api

## Install instructions
- Install `virtualenv`
- Create a new Python virtual environment with `virtualenv env`
- Activate the virtual environment with `virtualenv env`
- Install `requirements.txt` with `pip install -r requirements.txt`

## Alternative Docker install instructions
If you're familiar with Docker you can also install the system from the base Docker image.
```
docker build -t .
```


BrainMaps is a Python library for use with the [BrainMaps Platform](https://brainmaps.io)


